# cruscoplanets GUI

Graphic interface for the [cruscoplanets](https://pypi.org/project/cruscoplanets/) package

## Summary

Cruscoplanets is a tool for elaborating astrological charts according to the perspective of Morpurgo's astrological school. This package provides a GUI interface for it. To use it you have just to 
install this pip package and launch **cruscoplanets_gui** on your terminal, if you are on Linux; if you use Windows, you should have an executable file ready after you have installed the package.
